-- CREATE Role: atf COMMANDE SQL A UTILISER SEUL, SANS AUTRE COMMANDE SQL
CREATE ROLE atf LOGIN
  ENCRYPTED PASSWORD 'md5fb2a1e30a6b788e3890b4a5e7e457af1'
  SUPERUSER INHERIT CREATEDB NOCREATEROLE REPLICATION;

-- CREATE Database: "ATF" IDEM COMMANDE SQL A UTILISER SEUL, SANS AUTRE COMMANDE SQL
CREATE DATABASE "ATF"
  WITH OWNER = atf
       ENCODING = 'UTF8'
       TABLESPACE = pg_default
       LC_COLLATE = 'French_France.1252'
       LC_CTYPE = 'French_France.1252'
       CONNECTION LIMIT = -1;
--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------
--------------------------------------------------------------------------------------
-- CREATE FUNCTION maj_dateheure
CREATE OR REPLACE FUNCTION maj_dateheure()	
RETURNS TRIGGER AS $$
BEGIN
    NEW.dateheure = now();
    RETURN NEW;	
END;
$$ language 'plpgsql';

-- CREATE SEQUENCE client_autoincrement
CREATE SEQUENCE public.client_autoincrement
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
ALTER TABLE public.client_autoincrement
  OWNER TO postgres;
-- CREATE TABLE public.client
CREATE TABLE public.client
(
  clepk integer NOT NULL DEFAULT nextval('client_autoincrement'::regclass),
  nom character(60),
  prenom character(25),
  marque character(80),
  societe character(80),
  adresse1 character(40),
  adresse2 character(40),
  cp character(5),
  ville character(40),
  login character(120),
  motpasse character(40),
  logo bytea,
  inactif smallint DEFAULT 0,
  dateheure timestamp without time zone DEFAULT now(),
  CONSTRAINT client_pkey PRIMARY KEY (clepk)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE public.client
  OWNER TO postgres;
-- CREATE INDEX public.client_clepk_client_idx
  CREATE INDEX client_clepk_client_idx
  ON public.client
  USING btree
  (clepk);
-- CREATE INDEX public.client_login_idx
CREATE INDEX client_login_idx
  ON public.client
  USING btree
  (login COLLATE pg_catalog."default");
-- CREATE INDEX public.client_motpasse_idx
CREATE INDEX client_motpasse_idx
  ON public.client
  USING btree
  (motpasse COLLATE pg_catalog."default");
-- CREATE trigger update_client_dateheure
CREATE TRIGGER update_client_dateheure BEFORE UPDATE ON public.client FOR EACH ROW EXECUTE PROCEDURE maj_dateheure();
-- Ajout d'un utilisateur client
INSERT INTO public.client (nom,prenom,societe,marque,adresse1,adresse2,cp,ville,login,motpasse) VALUES('LAJOT-SARTHOU','Gilles','ECOR Informatique','ConviSAV','24B rue de l Ardoisière','','56220','ST JACUT LES PINS','GLS','123')

-- CREATE SEQUENCE reparation_autoincrement
CREATE SEQUENCE public.reparation_autoincrement
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
ALTER TABLE public.reparation_autoincrement
  OWNER TO postgres;
-- CREATE TABLE public.reparation
CREATE TABLE public.reparation
(
  clepk integer NOT NULL DEFAULT nextval('reparation_autoincrement'::regclass),
  date_creation date,
  clefk_client integer,
  cout real default 0,
  divers text,
  inactif smallint DEFAULT 0,
  dateheure timestamp without time zone DEFAULT now(),
  CONSTRAINT reparation_pkey PRIMARY KEY (clepk)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE public.reparation
  OWNER TO postgres;
-- CREATE INDEX public.reparation_clepk_idx
  CREATE INDEX reparation_clepk_idx
  ON public.reparation
  USING btree
  (clepk);
-- CREATE INDEX public.reparation_date_creation_idx
  CREATE INDEX reparation_date_creation_idx
  ON public.reparation
  USING btree
  (date_creation);
-- CREATE INDEX public.reparation_clefk_client_idx
  CREATE INDEX reparation_clefk_client_idx
  ON public.reparation
  USING btree
  (clefk_client);
-- CREATE trigger update_reparation_dateheure
CREATE TRIGGER update_reparation_dateheure BEFORE UPDATE ON public.reparation FOR EACH ROW EXECUTE PROCEDURE maj_dateheure();
  
-- CREATE SEQUENCE articlereparation_autoincrement
CREATE SEQUENCE public.articlereparation_autoincrement
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
ALTER TABLE public.articlereparation_autoincrement
  OWNER TO postgres;
-- CREATE TABLE public.articlereparation
CREATE TABLE public.articlereparation
(
  clepk integer NOT NULL DEFAULT nextval('articlereparation_autoincrement'::regclass),
  clefk_reparation integer,
  article character(60),
  reference character(20),
  nature character(40),
  cout real default 0,
  divers text,
  inactif smallint DEFAULT 0,
  dateheure timestamp without time zone DEFAULT now(),
  CONSTRAINT articlereparation_pkey PRIMARY KEY (clepk)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE public.articlereparation
  OWNER TO postgres;
-- CREATE INDEX public.articlereparation_clepk_idx
  CREATE INDEX articlereparation_clepk_idx
  ON public.articlereparation
  USING btree
  (clepk);
-- CREATE INDEX public.articlereparation_clefk_reparation_idx
  CREATE INDEX articlereparation_clefk_reparation_idx
  ON public.articlereparation
  USING btree
  (clefk_reparation);
-- CREATE INDEX public.articlereparation_reference_idx
  CREATE INDEX articlereparation_reference_idx
  ON public.articlereparation
  USING btree
  (reference COLLATE pg_catalog."default");
-- CREATE INDEX public.articlereparation_article_idx
  CREATE INDEX articlereparation_article_idx
  ON public.articlereparation
  USING btree
  (article COLLATE pg_catalog."default");
-- CREATE trigger update_articlereparation_dateheure
CREATE TRIGGER update_articlereparation_dateheure BEFORE UPDATE ON public.articlereparation FOR EACH ROW EXECUTE PROCEDURE maj_dateheure();

-- CREATE SEQUENCE nature_autoincrement
CREATE SEQUENCE public.nature_autoincrement
  INCREMENT 1
  MINVALUE 1
  MAXVALUE 9223372036854775807
  START 1
  CACHE 1;
ALTER TABLE public.nature_autoincrement
  OWNER TO postgres;
-- CREATE TABLE public.nature
CREATE TABLE public.nature
(
  clepk integer NOT NULL DEFAULT nextval('nature_autoincrement'::regclass),
  nature character(40),
  divers text,
  inactif smallint DEFAULT 0,
  dateheure timestamp without time zone DEFAULT now(),
  CONSTRAINT nature_pkey PRIMARY KEY (clepk)
)
WITH (
  OIDS=FALSE
);
ALTER TABLE public.nature
  OWNER TO postgres;
-- CREATE INDEX public.nature_clepk_idx
  CREATE INDEX nature_clepk_idx
  ON public.nature
  USING btree
  (clepk);
-- CREATE INDEX public.nature_nature_idx
  CREATE INDEX nature_nature_idx
  ON public.nature
  USING btree
  (nature COLLATE pg_catalog."default");
-- CREATE trigger update_articlereparation_dateheure
CREATE TRIGGER update_nature_dateheure BEFORE UPDATE ON public.nature FOR EACH ROW EXECUTE PROCEDURE maj_dateheure();

-- Mise à jour NATURE
INSERT public.nature (nature) values('TENTE');
INSERT public.nature (nature) values('AUVENT');
INSERT public.nature (nature) values('BLOUSON');
INSERT public.nature (nature) values('PARKA');
INSERT public.nature (nature) values('BONNET');
INSERT public.nature (nature) values('PANTALON');
INSERT public.nature (nature) values('BOTTE');